index.RangeIndex

|  | ## Cheshire3 Object Model: Class RangeIndex

Module index :: Class RangeIndex

## Class RangeIndex
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
            baseObjects.Index --+
                                |
                      SimpleIndex --+
                                    |
                                   RangeIndex

Instance Methods

search(self, session, clause, db) Search this particular index given a CQL clause, return a resultSet object
Inherited from `SimpleIndex`: `__init__`, `begin_indexing`, `commit_indexing`, `construct_item`, `construct_resultSet`, `delete_record`, `deserialise_terms`, `extract_data`, `index_record`, `merge_terms`, `scan`, `serialise_terms`, `store_terms` Inherited from `SimpleIndex` (private): `_handleConfigNode`, `_mergeHash`, `_processChain`, `_processRecord` Inherited from `baseObjects.Index`: `sort` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `SimpleIndex`: `currentFullPath`, `currentPath`, `debug`, `indexingData`, `indexingTerm`, `sources`, `storeOrig`, `xPathAllAbsolute`, `xPathAttributesRequired`, `xPathsNormalized` Inherited from `baseObjects.Index`: `indexStore` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### search(self, session, clause, db) | source code
Search this particular index given a CQL clause, return a resultSet object Overrides: SimpleIndex.search